% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/c5ml.R
\name{c5ls}
\alias{c5ls}
\title{Thurstone Case V solution to Paired Comparison Data
 with logistic probability}
\usage{
c5ls(f, n, ij, sname = NULL, minp = 1e-09, print = 1)
}
\arguments{
\item{f}{vector of # of times that the left object was preferred.}

\item{n}{vector of # of trials per pair  or  scalar .}

\item{ij}{matrix indicating the stimulus pair:  i, j.}

\item{sname}{a vector consisting of stimulus name \cr
When sname is NULL the elements of ij will be used as the names.}

\item{minp}{minimum value of probability when n=1.}

\item{print}{= 1 to print result.}
}
\value{
x The scale value \cr
sname Stimulus name \cr
n2o Name conversion table \cr
llh log likelihood \cr
maxag max value of the gradient vector \cr
varx The variance of the scale values \cr
errorvar The variance of the error term associated with x \cr
xs Scale values normalized to have unit variance \cr
errorvars The variance of the error term associated with xs \cr
xls LS scale values \cr
errorvalls The variance of xls \cr
iter # of iterations used. \cr
eps The convergence criterion \cr
}
\description{
Thurstone Case V solution to Paired Comparison Data
 with logistic probability
}
\details{
f_ij is the # of times that sutimulus i is preferred over stimulus j
 out of n_ij comparisons. \cr

 f/n will be converted to z by logit function and \cr
 z will be converted to the difference of centered scale values x.
}
\examples{
set.seed(1701)
x <- c(-.5,0,1)
ij <- matrix(c(2,1, 3,1, 3,2), 3,2, byrow=1)
ijc <- t( apply(4-ij,1, function(x) paste("s",x,sep="")) )
z <- c(x[2]-x[1], x[3]-x[1], x[3]-x[2])
p <- logistic(z)
n <- c(10,10,10)
f <- mapply( function(size,prob){ rbinom(1,size,prob) }, n, p )
res1 <- c5ls( f, n, ij )
res1 <- c5ls( f, n, ijc, sname=c("s33","s22","s11") )
}

