% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/c5ml.R
\name{c5ml}
\alias{c5ml}
\title{ML Solution to Thurstone Case V of Paired Comparison Data
 with logistic probability}
\usage{
c5ml(f, n, ij, sname = NULL, minp = 1e-09, lmax = 50, eps = 1e-06,
  print = 1)
}
\arguments{
\item{f}{vector of # of times that the left object was preferred.}

\item{n}{vector of # of trials per pair  or  scalar .}

\item{ij}{matrix indicating the stimulus pair:  i, j.
When sname is NULL the elements of ij will be used as the names.}

\item{minp}{minimum value of probability when n=1.}

\item{lmax}{max # of iterations.}

\item{eps}{criterion for convergence.}

\item{print}{= 1 to print result.}
}
\description{
ML Solution to Thurstone Case V of Paired Comparison Data
 with logistic probability
}
\details{
f_ij is the # of times that sutimulus i is preferred over stimulus j
 out of n_ij comparisons. \cr
 f_ij is assumed to have binomial distribution win n_ij and p_ij \cr
 where p_ij = logistic( x_i - x_j ).
}
\examples{
set.seed(1701)
x <- c(-.5,0,1)
ij <- matrix(c(2,1, 3,1, 3,2), 3,2, byrow=1)
ijc <- t( apply(4-ij,1, function(x) paste("s",x,sep="")) )
z <- c(x[2]-x[1], x[3]-x[1], x[3]-x[2])
p <- logistic(z)
n <- c(10,10,10)
f <- mapply( function(size,prob){ rbinom(1,size,prob) }, n, p )
res2 <- c5ml( f, n, ij )
res1 <- c5ml( f, n, ijc, sname=c("s33","s22","s11") )
}

